PyXMake Developer Guide: PyXMake.Build.Make.PyInstaller Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.PyInstaller Class Reference

Base class for all PyInstaller build events. More...

Inheritance diagram for PyXMake.Build.Make.PyInstaller:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| Encryption (self, encrypt, **kwargs)
| Preprocessing (self, cmdstring='')
| Build (self, mode="onefile", **kwargs)
| parse (cls, **kwargs)
| create (self, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
| __posix__ (self, **kwargs)
| AddIncludePath (self, includes)
| AddDependencyPath (self, dependencies)
| UseLibraries (self, libs)
| SourcePath (self, path)
| OutputPath (self, path, files="")
| Environment (self, path, script="ifortvars.bat")
| Postprocessing (self, cmdstring='')
| run (cls, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | MakeObjectKind = "PyInstaller"
| String identifier of current instance.
| buildtype = kwargs.get("type","onefile")
list | libs = []
list | libdirs = []
list | incdirs = []
| key_string = kwargs.get("key_string",''.join(random.choice(string.ascii_uppercase + string.ascii_lowercase + string.digits) for _ in range(16)))
| precmd = delimn.join([self.iniCompiler,cmdstring])
| Command executed during pre-build event.
str | makecmd = ""
list | makecmd = version.parse("64.0.0"): self.makecmd.insert(1,'--hidden-import=%s' % "requests")
| scrtdir
| temps = self.temps + (Utility.PathLeaf(new_path)+"c",)
| outdir
| srcdir
int | verbose = 1:
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid = BuildID
| Base string of build object.
list | srcs = []
| Source file or folders.
list | bare = not BuildID and not self.srcs
| stype = kwargs.get("stype",'Fortran')
| Source file type.
| verbose = verbose
| Level of verbosity of the current build object.
| hasFoss = kwargs.get("foss", Utility.GetExecutable("choco") or Utility.GetPlatform() in ["linux"] or kwargs.get("bash",False))
| Toggle between free open source software and commercial 3rd party libraries.
| scrtdir = os.getcwd()
| Current scratch directory
| srcdir = os.getcwd()
| Default search directory for source files.
| outdir = os.getcwd()
| Default search directory for output.
_, self.intelpath, self.iniCompiler | intelpath = content
| Path to Intel Fortran Compiler (read from Paths.log or empty).
tuple | temps = ()
| Tuple of data to be removed after job completion.
list | incdirs = []
| List of include directories.
list | libdirs = []
| List of library directories.
list | libs = []
| List of actual libraries (by name) used during linking.
list | copyfiles = []
| List of files to be copied to the output directory after finish.
str | iniCompiler = ""
| Default initialization of compiler script.
bool | setarch = True if kwargs.get('arch', None) in ['x86', 'x64'] else False
| Define the architecture for the build directly by using the keyword argument "arch".
| msvsc = kwargs.get("msvsc",'vs2015')
| Default version of Microsoft visual studio used by the Intel Fortran Compiler.
str | architecture = 'x86'
| Processor architecture.
str | postcmd = ""
| Post build command.
| buildname = self.temps + (inputfile, )
str | precmd = self.iniCompiler+" "+cmdstring
| Command executed during pre-build event.
| compargs = cmdstring
| Command line arguments passed in by the user.
str | makecmd = self.iniCompiler+" "+os.path.join(self.path2exe,self.exe)+" "+ cmd + cmdstring
| Command executed during build event.
| mkl_dependency

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Build.Make.Make
| __parser__ ()
| Detach ()
| F2CPreprocessing (PreprocessingFile)
| sanitize (string, **kwargs)
| setup (*args, **kwargs)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)
Protected Attributes inherited from PyXMake.Build.Make.Make
list | _mkl_includes = [x for x in self.incdirs if "mkl" in x]

## Detailed Description

Base class for all PyInstaller build events.

    Inherited class to build projects using PyInstaller.

Inherited from Make.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.PyInstaller.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of PyInstaller class object.

    @note Creates stand-alone application of Python scripts using PyInstaller.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2274 of file Make.py.

## Member Function Documentation

## ◆ Build()

PyXMake.Build.Make.PyInstaller.Build | ( |  | self,
|  |  | mode = "onefile",
|  | ** | kwargs )

    Switch build mode. Defaults to one single file.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2317 of file Make.py.

## ◆ create()

PyXMake.Build.Make.PyInstaller.create | ( |  | self,
|  | ** | kwargs )

    Execute make command

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2551 of file Make.py.

## ◆ Encryption()

PyXMake.Build.Make.PyInstaller.Encryption | ( |  | self,
|  |  | encrypt,
|  | ** | kwargs )

    Encrypt byte-code by using user-supplied or randomly generated key.

    @author: garb_ma
    @param encrypt: Boolean

Definition at line 2296 of file Make.py.

## ◆ parse()

PyXMake.Build.Make.PyInstaller.parse | ( |  | cls,
|  | ** | kwargs )

    Execute the current class as a CLI command.

Definition at line 2477 of file Make.py.

## ◆ Preprocessing()

PyXMake.Build.Make.PyInstaller.Preprocessing | ( |  | self,
|  |  | cmdstring = '' )

    Assemble command string for the pre-build event.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2307 of file Make.py.

## Member Data Documentation

## ◆ buildtype

PyXMake.Build.Make.PyInstaller.buildtype = kwargs.get("type","onefile")

Definition at line 2285 of file Make.py.

## ◆ incdirs

PyXMake.Build.Make.PyInstaller.incdirs = []

Definition at line 2290 of file Make.py.

## ◆ key_string

PyXMake.Build.Make.PyInstaller.key_string = kwargs.get("key_string",''.join(random.choice(string.ascii_uppercase + string.ascii_lowercase + string.digits) for _ in range(16)))

Definition at line 2304 of file Make.py.

## ◆ libdirs

PyXMake.Build.Make.PyInstaller.libdirs = []

Definition at line 2289 of file Make.py.

## ◆ libs

list PyXMake.Build.Make.PyInstaller.libs = []

Definition at line 2288 of file Make.py.

## ◆ makecmd [1/2]

PyXMake.Build.Make.PyInstaller.makecmd = ""

Definition at line 2338 of file Make.py.

## ◆ makecmd [2/2]

list PyXMake.Build.Make.PyInstaller.makecmd = version.parse("64.0.0"): self.makecmd.insert(1,'--hidden-import=%s' % "requests")

Definition at line 2340 of file Make.py.

## ◆ MakeObjectKind

str PyXMake.Build.Make.PyInstaller.MakeObjectKind = "PyInstaller"

String identifier of current instance.

Definition at line 2282 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.PyInstaller.outdir

Definition at line 2449 of file Make.py.

## ◆ precmd

PyXMake.Build.Make.PyInstaller.precmd = delimn.join([self.iniCompiler,cmdstring])

Command executed during pre-build event.

Definition at line 2314 of file Make.py.

## ◆ scrtdir

PyXMake.Build.Make.PyInstaller.scrtdir

Definition at line 2391 of file Make.py.

## ◆ srcdir

PyXMake.Build.Make.PyInstaller.srcdir

Definition at line 2461 of file Make.py.

## ◆ temps

PyXMake.Build.Make.PyInstaller.temps = self.temps + (Utility.PathLeaf(new_path)+"c",)

Definition at line 2392 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.PyInstaller.verbose = 1:

Definition at line 2470 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py